package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TdNotifyMapper;
import com.ruoyi.system.domain.TdNotify;
import com.ruoyi.system.service.ITdNotifyService;
import com.ruoyi.common.core.text.Convert;

/**
 * 检查通知Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-05-06
 */
@Service
public class TdNotifyServiceImpl implements ITdNotifyService 
{
    @Autowired
    private TdNotifyMapper tdNotifyMapper;

    /**
     * 查询检查通知
     * 
     * @param notifyId 检查通知主键
     * @return 检查通知
     */
    @Override
    public TdNotify selectTdNotifyByNotifyId(Long notifyId)
    {
        return tdNotifyMapper.selectTdNotifyByNotifyId(notifyId);
    }

    /**
     * 查询检查通知列表
     * 
     * @param tdNotify 检查通知
     * @return 检查通知
     */
    @Override
    public List<TdNotify> selectTdNotifyList(TdNotify tdNotify)
    {
        return tdNotifyMapper.selectTdNotifyList(tdNotify);
    }

    /**
     * 新增检查通知
     * 
     * @param tdNotify 检查通知
     * @return 结果
     */
    @Override
    public int insertTdNotify(TdNotify tdNotify)
    {
        return tdNotifyMapper.insertTdNotify(tdNotify);
    }

    /**
     * 修改检查通知
     * 
     * @param tdNotify 检查通知
     * @return 结果
     */
    @Override
    public int updateTdNotify(TdNotify tdNotify)
    {
        return tdNotifyMapper.updateTdNotify(tdNotify);
    }

    /**
     * 批量删除检查通知
     * 
     * @param notifyIds 需要删除的检查通知主键
     * @return 结果
     */
    @Override
    public int deleteTdNotifyByNotifyIds(String notifyIds)
    {
        return tdNotifyMapper.deleteTdNotifyByNotifyIds(Convert.toStrArray(notifyIds));
    }

    /**
     * 删除检查通知信息
     * 
     * @param notifyId 检查通知主键
     * @return 结果
     */
    @Override
    public int deleteTdNotifyByNotifyId(Long notifyId)
    {
        return tdNotifyMapper.deleteTdNotifyByNotifyId(notifyId);
    }
}
